-- PROGRAM-NAME: AddQDBMCLEntry.rex  BACKUP-REQUIRED: Yes            
-- AUTHOR: Tony Dycks                REVISED BY: Tony Dycks          
-- DATE-WRITTEN: January 18, 2008    DATE-REVISED: August 9, 2020     
-- LANGUAGE: BSF4ooRexx              VERSION. NO.: v641 Beta with ooRexx 4.2              
-- PLATFORM: Windows/Linux (Console) VERSION. NO.: Java 8 SE or JDK 
--                                                                   
-- DESCRIPTION:                                                      
--    Add QDBM Key => Value Pair Command Line Arguments To QDBM Filespec Specified 
--    As The First Command Line Argument.  Key Is The Second Command Line Argument.
--    Value Is The Third Command Line Argument.                        
--
-- PRE-REQUISITE(S):
--   1. Installation of QDBM Library API Dev Library & Dependencies
--      sudo apt-get install libqdbm-dev
--      sudo yum install libqdbm-devel 
--   or Build of QDBM API Library Source
--      su (for /usr/local configure and make)
--      ./configure
--      make
--      make check
--      make install
--      cp /usr/local/lib/libqdbm* /usr/lib
--   2. Setup of QDBM Library For Java Package
--      sudo apt-get install qdbm-java  {Debian Linux}
--   or Build of QDBM Library Source For Java 
--      cd java
--      su
--      Modify configure.in File for $JAVA_HOME
--      ./configure
--      make
--      make check
--      make install
--      cp /usr/local/lib/*qdbm* /usr/lib
--   3. Copy qdbm.jar File to $JAVA_HOME/jre/lib/ext Directory
-- 
-- REVISION HISTORY:                                                         
--   Version  Description                                                    
--   -------  -------------------------------------------------------------  
--     1.0    Original Implementation                                        
--            T. Dycks -- January 18, 2008
--     1.1    Revised Documentation Content
--            T. Dycks -- May 13, 2020
--     1.2    Updated Documentation And Retested
--            T. Dycks -- August 9, 2020
--
-- USAGE:                                                            
--   rexx AddQDBMCLEntry.rex <QDBM-Filename> <LookupKey> <Value> <Enter>     
--                                                                   
-- USAGE EXAMPLE(S):                                                    
--   sh ./rexxj2.sh  AddQDBMCLEntry.rex $HOME/qdbm/appl/eclipsehorseofyr.qdb 2020 "Tiz The Law" <Enter> {Windows}
--   rexx AddQDBMCLEntry.rex C:\Storage\qdbm\appl\walklog.qdb 2007-12-28 4 <Enter> {Linux}
--                                                                   
-- REFERENCES:                                                               
--   Specifications of QDBM for Java
--   Copyright (C) 2000-2006 Mikio Hirabayashi
--   Last Update: Thu, 26 Oct 2006
--   Examples 
-- URL:
--   https://fallabs.com/qdbm/jspex.html#examples    

if rxFuncQuery("BSF") then  /* no bsf4rexx support available yet, hence load Java */
  do
   call rxFuncAdd "BsfLoadFuncs", "BSF4Rexx", "BsfLoadFuncs"
   call BsfLoadFuncs    /* load all BSF-functions                    */
   call BsfLoadJava     /* load the JVM and set up BSF4Rexx-support  */
  end

if BsfInvokedBy()=1 then say "This Rexx program was invoked by Java!"
else if BsfInvokedBy()=2 then say "This Rexx program was invoked by Rexx, JVM loaded by Rexx!"
else say "No JVM present, we got troubles ..."

Depot = bsf.import("qdbm.Depot")    --  QDBM Access Module (Jar File in JRE Lib Extensions Directory)

parse arg QDBMFile KeyName argValue

say ' '
say 'AddQDBMCLEntry.rex -- BSF4ooRexx Add QDBM Key And Value For File, Key and Value Entered On Command Line'
say 'Version 1.2'
say 'Written By: Tony Dycks'
say 'Revised By: Tony Dycks'
say 'Date Written: January 18, 2008'
say 'Date Revised: August 9, 2020'
say ' '
say 'QDBM Filename Argument: ' || QDBMFile
say 'Lookup Name Key: ' KeyName
say ' '

say 'Opening Quick DBM File ...'
dbm = Depot~new(QDBMFile, Depot~OWRITER, -1)
say 'Storing Entry: Key [' || KeyName || '] Value [' || argValue '] ...'
dbm~put(box('String', KeyName)~getBytes(), box('String', argValue)~getBytes())
dbm~close()

say ' '
say '>>> End Of Program --  AddQDBMCLEntry.rex <<<'
say ' '

::requires bsf.cls /* BSF4Rexx Class File */
