-- PROGRAM-NAME: LstQDBMCLEntry.nrx  BACKUP-REQUIRED: Yes                
-- AUTHOR: Tony Dycks                REVISED BY: Tony Dycks              
-- DATE-WRITTEN: July 22, 2006       DATE-REVISED: May 4, 2020           
-- LANGUAGE: BSF4ooRexx              VERSION. NO.: ooRexx 4.2            
-- PLATFORM: Windows/Linux (Console) VERSION. NO.: Any With Java SDK     
--                                                                       
-- DESCRIPTION:                                                          
--    List RPMInst Table Rows Matching Search String Specified As        
--    The Second Command Line Argument.                                  
--                                                                       
--    First Command Line Argument Specifies The Filepath of The          
--    SQLite Database File.                                              
-- PRE-REQUISITE(S):
--   1. Installation of QDBM Library API Dev Library & Dependencies
--      sudo apt-get install libqdbm-dev
--      sudo yum install libqdbm-devel 
--   or Build of QDBM API Library Source
--      su (for /usr/local configure and make)
--      ./configure
--      make
--      make check
--      make install
--      cp /usr/local/lib/libqdbm* /usr/lib
--   2. Setup of QDBM Library For Java Package
--      sudo apt-get install qdbm-java  {Debian Linux}
--   or Build of QDBM Library Source For Java 
--      cd java
--      su
--      Modify configure.in File for $JAVA_HOME
--      ./configure
--      make
--      make check
--      make install
--      cp /usr/local/lib/*qdbm* /usr/lib
--   3. Copy qdbm.jar File to $JAVA_HOME/jre/lib/ext Directory
-- 
-- REVISION HISTORY:                                                         
--   Version  Description                                                    
--   -------  -------------------------------------------------------------  
--     1.0    Original Implementation                                        
--              T. Dycks -- January 18, 2008
--     1.1    Removed BSF RegisterBean Function; Changed to BSF Import
--            Revised Documentation Content
--              T. Dycks -- May 13, 2020
--                                                                    
-- USAGE:                                                                
--   sh ./rexxj2.sh LstQDBMCLEntry.rex <QDBM-Filename> <LookupKey> <Enter>         
--                                                                       
-- USAGE EXAMPLE:                                                        
--   sh ./rexxj2.sh LstQDBMCLEntry.rex $HOME/qdbm/appl/eclipsehorseofyr.qdb 1975                                                 
--                                                                       
-- REFERENCES:                                                               
--   Specifications of QDBM for Java
--   Copyright (C) 2000-2006 Mikio Hirabayashi
--   Last Update: Thu, 26 Oct 2006
--   Examples 
-- URL:
--   https://fallabs.com/qdbm/jspex.html#examples                                                           

if rxFuncQuery("BSF") then  /* no bsf4rexx support available yet, hence load Java */
  do
   call rxFuncAdd "BsfLoadFuncs", "BSF4Rexx", "BsfLoadFuncs"
   call BsfLoadFuncs    /* load all BSF-functions                    */
   call BsfLoadJava     /* load the JVM and set up BSF4Rexx-support  */
  end

if      BsfInvokedBy()=1 then say "This Rexx program was invoked by Java!"
else if BsfInvokedBy()=2 then say "This Rexx program was invoked by Rexx, JVM loaded by Rexx!"
else                          say "No JVM present, we got troubles ..."

parse arg QDBMFile KeyName

Depot = bsf.import("qdbm.Depot")  /* Import Java Class "qdbm.Depot" */
DepotException = bsf.import("qdbm.DepotException") /* DepotException Class */
de = DepotException~new()
dbm = Depot~new(QDBMFile, Depot~OREADER, -1)

say ' '
say 'LstQDBMCLEntry.nrx -- BSF4ooRexx List QDBM Value For QDBM File & Key Entered On Command Line'
say 'Version 1.0'
say 'Written By: Tony Dycks'
say 'Revised By: Tony Dycks'
say 'Date Written: July 22, 2006'
say 'Date Revised: May 13, 2020'
say ' '
say 'QDBM Filename Argument: ' || QDBMFile
say 'Lookup Name Key: ' || KeyName
say ' '
say 'Opening Quick DBM File ...'
say 'Retrieving Entry ...'
joKey = box('String', KeyName)
joKeyBytes = joKey~getBytes()
res = dbm~get(joKeyBytes)
jores = box('String', res)
say 'Key Name: ' || KeyName ' => Value: ' || jores~toString()
dbm~close()

say ' '
say '>>> End Of Program -- LstQDBMCLEntry.nrx <<<'
say ' '

::requires bsf.cls /* BSF4Rexx Class File */
