-- PROGRAM-NAME: QDBMDepotVer.rex          BACKUP-REQUIRED: Yes           
-- AUTHOR: Tony Dycks                      REVISED BY: Tony Dycks         
-- DATE-WRITTEN: July 28, 2006             DATE-REVISED: May 14, 2020 
-- LANGUAGE: Open Object Rexx/BSF4Rexx     VERSION. NO.: 4.2 / v641 Beta           
-- PLATFORM: Windows/Linux (Console Shell) VERSION. NO.: Any              
--                                                                        
-- DESCRIPTION:                                                           
--   Display The Version Of The QDBM Depot API Using Bean Scripting For         
--   Rexx (BSF4Rexx) Scripting Language with Open Object Rexx. QDBM File
--   Is Entered As A Command Line Argument.
--
-- PRE-REQUISITE(S):
--   1. Installation of QDBM Library API Dev Library & Dependencies
--      sudo apt-get install libqdbm-dev
--      sudo yum install libqdbm-devel 
--   or Build of QDBM API Library Source
--      su (for /usr/local configure and make)
--      ./configure
--      make
--      make check
--      make install
--      cp /usr/local/lib/libqdbm* /usr/lib
--   2. Setup of QDBM Library For Java Package
--      sudo apt-get install qdbm-java  {Debian Linux}
--   or Build of QDBM Library Source For Java 
--      cd java
--      su
--      Modify configure.in File for $JAVA_HOME
--      ./configure
--      make
--      make check
--      make install
--   3. Copy qdbm.jar File to $JAVA_HOME/jre/lib/ext Directory
--  
-- REVISION HISTORY:                                                         
--   Version  Description                                                    
--   -------  -------------------------------------------------------------  
--     1.0    Original Implementation                                        
--            T. Dycks -- July 28, 2006
--     1.1    Revised Documentation Content; Added Call to SysFileTree to 
--            Get Last Modified Date of File Argument
--            T. Dycks -- May 14, 2020
--
-- USAGE:                                                                 
--   ./rexxj.sh QDBMDepotVer.rex <Enter>  {Linux}                         
--   rexx QDBMDepotVer.rex <Enter>        {Windows}                       
--                                                                        
-- USAGE EXAMPLES:                                                        
--   ./rexxj.sh QDBMDepotVer.rex <Enter>  {Linux}                         
--   rexx QDBMDepotVer.rex <Enter>        {Windows}                       
--                                                                        
-- REFERENCES:                                                               
--   Specifications of QDBM for Java
--   Copyright (C) 2000-2006 Mikio Hirabayashi
--   Last Update: Thu, 26 Oct 2006
--   Examples 
-- URL:
--   https://fallabs.com/qdbm/jspex.html#examples                                                     

if rxFuncQuery("BSF") then  /* no bsf4rexx support available yet, hence load Java */
  do
   call rxFuncAdd "BsfLoadFuncs", "BSF4Rexx", "BsfLoadFuncs"
   call BsfLoadFuncs    /* load all BSF-functions                    */
   call BsfLoadJava     /* load the JVM and set up BSF4Rexx-support  */
  end

if      BsfInvokedBy()=1 then say "This Rexx program was invoked by Java!"
else if BsfInvokedBy()=2 then say "This Rexx program was invoked by Rexx, JVM loaded by Rexx!"
else                          say "No JVM present, we got troubles ..."

parse arg qdbmfile

call SysFileTree qdbmfile, dtinfo., "L"

dbm = bsf.import('qdbm.Depot')

say
say 'QDBMDepotVer.rex -- Display QDBM Depot Hash File API Version'
say 'Written By: Tony Dycks'
say 'Revised By: Tony Dycks'
say 'Date Written: July 28, 2006'
say 'Date Revised: May 14, 2020'
say
say 'QDBM Filename:' qdbmfile
say ''
say 'Date Last Modified:' 
say dtinfo.1
say ''
say 'Depot Version:' dbm~version()
say
say '>>> End Of Program -- QDBMDepotVer.rex <<<'
say

::requires bsf.cls   /* BSF4Rexx Class File */
