-- PROGRAM-NAME: QDBMRecCnt.rex            BACKUP-REQUIRED: Yes          
-- AUTHOR: Tony Dycks                      REVISED BY: Tony Dycks        
-- DATE-WRITTEN: April 28, 2020            DATE-REVISED: May 13, 2020 
-- LANGUAGE: Open Object Rexx/BSF4Rexx     VERSION. NO.: 4.2 / v641 Beta          
-- PLATFORM: Windows/Linux (Console Shell) VERSION. NO.: Any             
--                                                                       
-- DESCRIPTION:                                                          
--   Display Record Count For QDBM File Command Line Argument Using Bean 
--   Scripting For Rexx (BSF4Rexx) Scripting Language.                                 
--
-- PRE-REQUISITE(S):
--   1. Installation of QDBM Library API Dev Library & Dependencies
--      sudo apt-get install libqdbm-dev
--      sudo yum install libqdbm-devel 
--   or Build of QDBM API Library Source
--      su (for /usr/local configure and make)
--      ./configure
--      make
--      make check
--      make install
--      cp /usr/local/lib/libqdbm* /usr/lib
--   2. Setup of QDBM Library For Java Package
--      sudo apt-get install qdbm-java  {Debian Linux}
--   or Build of QDBM Library Source For Java 
--      cd java
--      su
--      Modify configure.in File for $JAVA_HOME
--      ./configure
--      make
--      make check
--      make install
--      cp /usr/local/lib/*qdbm* /usr/lib
--   3. Copy qdbm.jar File to $JAVA_HOME/jre/lib/ext Directory
-- 
-- REVISION HISTORY:                                                         
--   Version  Description                                                    
--   -------  -------------------------------------------------------------  
--     1.0    Original Implementation                                        
--            T. Dycks -- April 28, 2020
--     1.1    Revised Documentation Content
--            T. Dycks -- May 13, 2020
--
-- USAGE:                                                                
--   ./rexxj.sh QDBMRecCnt.rex <QDBM-Filename> <Enter>  {Linux}          
--   rexx QDBMRecCnt.rex <QDBM-Filename> <Enter>        {Windows}        
--                                                                       
-- USAGE EXAMPLES:                                                       
--   ./rexxj.sh QDBMRecCnt.rex $HOME/qdbm/appl/walklog.qdb <Enter>  {Linux}                          
--   rexx QDBMRecCnt.rex C:\Storage\qdbm\appl\walklog.qdb <Enter>   {Windows}                        
--                                                                       
-- REFERENCES:                                                               
--   Specifications of QDBM for Java
--   Copyright (C) 2000-2006 Mikio Hirabayashi
--   Last Update: Thu, 26 Oct 2006
--   Examples 
-- URL:
--   https://fallabs.com/qdbm/jspex.html#examples                                                        

if rxFuncQuery("BSF") then  /* no bsf4rexx support available yet, hence load Java */
  do
   call rxFuncAdd "BsfLoadFuncs", "BSF4Rexx", "BsfLoadFuncs"
   call BsfLoadFuncs    /* load all BSF-functions                    */
   call BsfLoadJava     /* load the JVM and set up BSF4Rexx-support  */
  end

if      BsfInvokedBy()=1 then say "This Rexx program was invoked by Java!"
else if BsfInvokedBy()=2 then say "This Rexx program was invoked by Rexx, JVM loaded by Rexx!"
else                          say "No JVM present, we got troubles ..."

parse arg qdbmfile

Depot = bsf.import('qdbm.Depot')
dbm = Depot~new(QDBMFile, Depot~OREADER, -1)

say
say 'QDBMRecCnt.rex -- Display Record Count For QDBM File Command Line Argument'
say 'Version 1.0'
say 'Written By: Tony Dycks'
say 'Revised By: Tony Dycks'
say 'Date Written: April 28, 2020'
say 'Date Revised: May 13, 2020'
say
say 'QDBM File:' qdbmfile
say 'Record Count:' dbm~rnum()
dbm~close()
say
say '>>> End Of Program -- QDBMRecCnt.rex <<<'
say

::requires bsf.cls   /* BSF4Rexx Class File */
