-- PROGRAM-NAME: listqdbm.rex        BACKUP-REQUIRED: Yes            
-- AUTHOR: Tony Dycks                REVISED BY: Tony Dycks          
-- DATE-WRITTEN: January 16, 2008    DATE-REVISED: May 13. 2020     
-- LANGUAGE: BSF4ooRexx              VERSION NO.: Beta v641 for 4.2              
-- PLATFORM: Windows/Linux (Console) VERSION NO.: Java 8 SE or JDK 
--                                                                   
-- DESCRIPTION:                                                      
--   List QDBM Records For The Command Line Argument Specifing The Filepath of      
--   The QDBM Database File.                                          
--
-- PRE-REQUISITE(S):
--   1. Installation of QDBM Library API Dev Library & Dependencies
--      sudo apt-get install libqdbm-dev
--      sudo yum install libqdbm-devel 
--   or Build of QDBM API Library Source
--      su (for /usr/local configure and make)
--      ./configure
--      make
--      make check
--      make install
--      cp /usr/local/lib/libqdbm* /usr/lib
--   2. Setup of QDBM Library For Java Package
--      sudo apt-get install qdbm-java  {Debian Linux}
--   or Build of QDBM Library Source For Java 
--      cd java
--      su
--      Modify configure.in File for $JAVA_HOME
--      ./configure
--      make
--      make check
--      make install
--      cp /usr/local/lib/*qdbm* /usr/lib
--   3. Copy qdbm.jar File to $JAVA_HOME/jre/lib/ext Directory
--
-- REVISION HISTORY:                                                         
--   Version  Description                                                    
--   -------  -------------------------------------------------------------  
--     1.0    Original Implementation                                        
--            T. Dycks -- January 16, 2008
--     1.1    Revised Documentation Content
--            T. Dycks -- May 13, 2020
--
-- USAGE:                                                            
--   sh ./rexxj.sh listqdbm.rex <QDBM-Filename> <Enter> {Linux}
--   rexxj istqdbm.rex <QDBM-Filename> <Enter> {Windows}
--                                                                   
-- USAGE EXAMPLE(S):                                                    
--   rexxj.sh listqdbm.rex $HOME/qdbm/eclipsehorseofyr.qdb <Enter>   {Linux}   
--   rexxj listqdbm.rex C:\Storage\qdbm\eclipsehorseofyr.qdb <Enter> {Windows}
--                                                                   
-- REFERENCES:                                                               
--   Specifications of QDBM for Java
--   Copyright (C) 2000-2006 Mikio Hirabayashi
--   Last Update: Thu, 26 Oct 2006
--   Examples 
-- URL:
--   https://fallabs.com/qdbm/jspex.html#examples  

if rxFuncQuery("BSF") then  /* no bsf4rexx support available yet, hence load Java */
  do
   call rxFuncAdd "BsfLoadFuncs", "BSF4Rexx", "BsfLoadFuncs"
   call BsfLoadFuncs    /* load all BSF-functions                    */
   call BsfLoadJava     /* load the JVM and set up BSF4Rexx-support  */
  end

if      BsfInvokedBy()=1 then say "This Rexx program was invoked by Java!"
else if BsfInvokedBy()=2 then say "This Rexx program was invoked by Rexx, JVM loaded by Rexx!"
else                          say "No JVM present, we got troubles ..."

parse arg QDBMFile

Depot = bsf.import("qdbm.Depot")  /* Import Java Class "qdbm.Depot" */
dbm = Depot~new(QDBMFile, Depot~OREADER, -1)

/*  QDBM Access Module (Jar Files in JRE Lib Extensions Directory */

say ' '
say 'listqdbm.rex -- BSF4Rexx List QDBM Key Values For QDBM File Entered On Command Line'
say 'Version 1.1'
say 'Written By: Tony Dycks'
say 'Revised By: Tony Dycks'
say 'Date Written: January 16, 2008'
say 'Date Revised: May 13. 2020'
say ' '
say 'QDBM Filename Argument: ' || QDBMFile
say ' '

reccnt = 0

say 'Opening Quick DBM File ...'
maxrecs = dbm~rnum()
say 'Listing Entries ...'
say 'Total Entries: ' || maxrecs
say ' '
KeyName = dbm~firstkey()
joKeyName = box('String', KeyName)
res = dbm~get(KeyName)
jores = box('String', res)
reccnt = reccnt + 1
say reccnt || ': Key Name: ' || joKeyName~toString() || ' => Value: ' || jores~toString()

do while reccnt < maxrecs
  KeyName = dbm~nextkey()
	joKeyName = box('String', KeyName)
  res = dbm~get(KeyName)
	jores = box('String', res)
  reccnt = reccnt + 1
	say reccnt || ': Key Name: ' || joKeyName~toString() || ' => Value: ' || jores~toString()
end

dbm~close()

say ' '
say '>>> End Of Program --  listqdbm.rex <<<'
say ' '

::requires bsf.cls /* BSF4Rexx Class File */