-- PROGRAM-NAME: listtchash.rex      BACKUP-REQUIRED: Yes            
-- AUTHOR: Tony Dycks                REVISED BY: Tony Dycks          
-- DATE-WRITTEN: May 5, 2020         DATE-REVISED: May 13, 2020     
-- LANGUAGE: BSF4ooRexx              VERSION NO.: v641 for 4.2              
-- PLATFORM: Windows/Linux (Console) VERSION NO.: Java 8 SE or JDK 
--                                                                   
-- DESCRIPTION:                                                      
--    List TC Hash DB Records For The Command Line Argument Specifing The Filepath of The      
--    Tokyo Cabinet Database File.                                          
--
-- PRE-REQUISITE(S):
--   1. Installation of Tokyo Cabinet Library API Dev Library & Dependencies
--      sudo apt-get install tokyocabinet-dev
--      sudo yum install tokyocabinet-devel 
--   or Build of Tokyo Cabinet API Library Source
--      su (for /usr/local configure and make)
--      ./configure
--      make
--      make check
--      make install
--      cp /usr/local/lib/libqdbm* /usr/lib
--   2. Setup of Tokyo Cabinet Library For Java Package
--      sudo apt-get install qdbm-java  {Debian Linux}
--   or Build of Tokyo Cabinet Library Source For Java 
--      cd java
--      su
--      Modify configure.in File for $JAVA_HOME
--      ./configure
--      make
--      make check
--      make install
--      cp /usr/local/lib/*qdbm* /usr/lib
--   3. Copy toykocabinet.jar File to $JAVA_HOME/jre/lib/ext Directory
--      cp /usr/local/lib/tokyocabinet.jar $JAVA_HOME/jre/lib/ext
--
-- REVISION HISTORY:                                                         
--   Version  Description                                                    
--   -------  -------------------------------------------------------------  
--     1.0    Original Implementation                                        
--            T. Dycks -- May 5, 2020
--     1.1    Revised Documentation Content
--            T. Dycks -- May 13, 2020
--     
-- USAGE:                                                            
--   sh ./rexxj.sh listtchash.rex <TCHashDB-Filename> <Enter> {Linux}
--   rexx listtchash.rex <TCHashDB-Filename> <Enter> {Windows or Linux}
--                                                                   
-- USAGE EXAMPLE:                                                    
--   sh ./rexxj.sh listtchash.rex $HOME/tokyocab/appl/eclipsehorseofyr.tch <Enter> {Linux}   
--   rexx listtchash.rex $HOME/tokyocab/appl/eclipsehorseofyr.tch <Enter> {Linux}
--                                                                   
-- REFERENCE(S):
--   Tokyo Cabinet: a modern implementation of DBM
--   Copyright (C) 2006-2011 FAL Labs
--   Last Update: Thu, 05 Aug 2010 
-- URL:
--   https://fallabs.com/tokyocabinet/
-- ================================================================================
--   Fallabs.com -- Presentation -- Introduction to Tokyo Products PDF 
-- URL:
--   https://fallabs.com/tokyocabinet/tokyoproducts.pdf
-- ================================================================================
--   Fallabs.com -- Specifications of the Java API
-- URL:
--   https://fallabs.com/tokyocabinet/javadoc/

if rxFuncQuery("BSF") then  /* no bsf4rexx support available yet, hence load Java */
do
   call rxFuncAdd "BsfLoadFuncs", "BSF4Rexx", "BsfLoadFuncs"
   call BsfLoadFuncs    /* load all BSF-functions                    */
   call BsfLoadJava     /* load the JVM and set up BSF4Rexx-support  */
end

if      BsfInvokedBy()=1 then say "This Rexx program was invoked by Java!"
else if BsfInvokedBy()=2 then say "This Rexx program was invoked by Rexx, JVM loaded by Rexx!"
else                          say "No JVM present, we got troubles ..."

parse arg TCHDBFile

/*  TCH DB Access Module (Jar Files in JRE Lib Extensions Directory */
HDB = bsf.import("tokyocabinet.HDB")  /* Import Java Class "tokyocabinet.HDB" */
tchdb = HDB~new()
tchdb~open(TCHDBFile, HDB~OREADER)

say ' '
say 'listtchash.rex -- BSF4Rexx List TCH DB Key Values For TC Hash DB File Entered On Command Line'
say 'Version 1.1'
say 'Written By: Tony Dycks'
say 'Revised By: Tony Dycks'
say 'Date Written: May 5, 2020'
say 'Date Revised: May 13, 2020'
say ' '
say 'TC Hash DB Filename Argument: ' || TCHDBFile
say ' '

reccnt = 0

say 'Opening Tokyo Cabinet Hash File ...'
maxrecs = tchdb~rnum()
say 'Listing Entries ...'
say 'Total Entries: ' || maxrecs
say ' '

if tchdb~iterinit() then
  do while reccnt < maxrecs
    KeyName = tchdb~iternext()
    reccnt = reccnt + 1
    joKeyName = box('String', KeyName)
    res = tchdb~get(KeyName)
    jores = box('String', res)
    say reccnt || ': Key Name: ' || joKeyName~toString() || ' => Value: ' || jores~toString()
  end

tchdb~close()

say ' '
say '>>> End Of Program --  listtchash.rex <<<'
say ' '

::requires bsf.cls /* BSF4Rexx Class File */