-- PROGRAM-NAME: listtchval4key.rex  BACKUP-REQUIRED: Yes            
-- AUTHOR: Tony Dycks                REVISED BY: Tony Dycks          
-- DATE-WRITTEN: May 5, 2020         DATE-REVISED: May 13, 2020     
-- LANGUAGE: BSF4ooRexx              VERSION NO.: v641 Beta for 4.2              
-- PLATFORM: Windows/Linux (Console) VERSION NO.: Java 8 SE or JDK 
--                                                                   
-- DESCRIPTION:                                                      
--    List TC Hash DB Record For The Command Line Argument Specifing The Filepath of The      
--    Tokyo Cabinet Database File And The Search Key.                                          
--
-- PRE-REQUISITE(S):
--   1. Installation of Tokyo Cabinet Library API Dev Library & Dependencies
--      sudo apt-get install tokyocabinet-dev
--      sudo yum install tokyocabinet-devel 
--   or Build of Tokyo Cabinet API Library Source
--      su (for /usr/local configure and make)
--      ./configure
--      make
--      make check
--      make install
--      cp /usr/local/lib/libtokyo* /usr/lib
--   2. Setup of Tokyo Cabinet Library For Java Package
--      sudo apt-get install qdbm-java  {Debian Linux}
--   or Build of Tokyo Cabinet Library Source For Java 
--      cd java
--      su
--      Modify configure.in File for $JAVA_HOME
--      ./configure
--      make
--      make check
--      make install
--      cp /usr/local/lib/*tokyo* /usr/lib
--      cp /usr/local/lib/tokyocabinet.jar $JAVA_HOME/jre/lib/ext
--
-- REVISION HISTORY:                                                         
--   Version  Description                                                    
--   -------  -------------------------------------------------------------  
--     1.0    Original Implementation                                        
--            T. Dycks -- May 5, 2020
--     1.1    Revised Documentation Content
--            T. Dycks -- May 13, 2020
--
-- USAGE:                                                            
--   rexxj.sh listtchval4key.rex <TCHashDB-Filename> <Enter> {Linux}
--   rexxj listtchval4key.rex <TCHashDB-Filename> <Enter> {Windows}
--                                                                   
-- USAGE EXAMPLE:                                                    
--   rexxj.sh listtchval4key.rex $HOME/tokyocab/appl/eclipsehorseofyr.tch 
--            2019 <Enter>  {Linux}   
--   rexx listtchval4key.rex $HOME/tokyocab/appl/eclipsehorseofyr.tch
--            1973 <Enter>  {Linux}
--                                                                   
-- REFERENCE(S):
--   Tokyo Cabinet: a modern implementation of DBM
--   Copyright (C) 2006-2011 FAL Labs
--   Last Update: Thu, 05 Aug 2010 
-- URL:
--   https:--fallabs.com/tokyocabinet/
-- ================================================================================
--   Fallabs.com -- Presentation -- Introduction to Tokyo Products PDF 
-- URL:
--   https:--fallabs.com/tokyocabinet/tokyoproducts.pdf
-- ================================================================================
--   Fallabs.com -- Specifications of the Java API
-- URL:
--   https://fallabs.com/tokyocabinet/javadoc/

if rxFuncQuery("BSF") then  /* no bsf4rexx support available yet, hence load Java */
do
   call rxFuncAdd "BsfLoadFuncs", "BSF4Rexx", "BsfLoadFuncs"
   call BsfLoadFuncs    /* load all BSF-functions                    */
   call BsfLoadJava     /* load the JVM and set up BSF4Rexx-support  */
end

if      BsfInvokedBy()=1 then say "This Rexx program was invoked by Java!"
else if BsfInvokedBy()=2 then say "This Rexx program was invoked by Rexx, JVM loaded by Rexx!"
else                          say "No JVM present, we got troubles ..."

parse arg TCHDBFile SrchKey

/*  TCH DB Access Module (Jar Files in JRE Lib Extensions Directory */
HDB = bsf.import("tokyocabinet.HDB")  /* Import Java Class "tokyocabinet.HDB" */
tchdb = HDB~new()
tchdb~open(TCHDBFile, HDB~OREADER)

say ' '
say 'listtchval4key.rex -- BSF4ooRexx List TCH DB Key Value For TC Hash DB File' 
say 'And Search Key Entered As Command Line Arguments'
say 'Version 1.0'
say 'Written By: Tony Dycks'
say 'Revised By: Tony Dycks'
say 'Date Written: May 5, 2020'
say 'Date Revised: May 13, 2020'
say ' '
say 'TC Hash DB Filename Argument: ' || TCHDBFile
say ' '

reccnt = 0

say 'Opening Tokyo Cabinet Hash File ...'
say 'Searching for Key: ' || SrchKey || '...'
res = tchdb~get(SrchKey)
say ''
say 'Key: ' || SrchKey || ' => Value: ' || res

tchdb~close()

say ' '
say '>>> End Of Program --  listtchval4key.rex <<<'
say ' '

::requires bsf.cls /* BSF4Rexx Class File */