// PROGRAM-NAME: LdQDBMHorseOfYr.java      BACKUP-REQUIRED: Yes
// AUTHOR: Tony Dycks                      REVISED-BY: Tony Dycks
// DATE-WRITTEN: April 27, 2020            DATE-REVISED: April 27, 2020
// LANGUAGE: Java 8 SE                     VERSION NO.: 1.8+
// PLATFORM: Windows/Linux (Command Shell) VERSION NO.: 7/10 / CentOs/Debian
//
// DESCRIPTION:
//   Load QDBM File With Eclipse Horse of The Year Data Using QDBM Depot
//
// PRE-REQUISITE(S):
//   1. Download And Installation of qdbm-java Linux Package or QDBM Java
//      Depot .jar File
//
// REVISION HISTORY:
//   Version  Change Description
//   =======  ====================================================
//     1.0    Original Implementation
//              T. Dycks -- April 27-28, 2020
//
// COMPILE:
//   javac LdQDBMHorseOfYr.java  <Enter>
//
// USAGE:
//   java LdQDBMHorseOfYr.java <HorseOfTheYr-CSV-File> <Enter>
//
// USAGE EXAMPLE(S):
//   java LdQDBMHorseOfYr /home/tonyd/txtfiles/eclipsehorseofyr.txt <Enter>
//
// REFERENCE(S):
//   Specifications of QDBM for Java
//   Copyright (C) 2000-2006 Mikio Hirabayashi
//   Last Update: Thu, 26 Oct 2006 
//   Examples
// URL:
//   https://fallabs.com/qdbm/jspex.html#examples
// =====================================================================================
//   Javarevisited -- How to get Environment Variables in Java- Example Tutorial 
// URL:
//   https://javarevisited.blogspot.com/2012/08/how-to-get-environment-variables-in.html
//
import java.io.*;
import qdbm.*;

public class LdQDBMHorseOfYr
  {
  public static void main(String args[])
    {
	  banner();
    Depot depot = null;
    // Open the QDBM Database File; Create It If Necessary
    String sQDBMFileNm = getqdbmfilenm();
    try
      {
      depot = new Depot(sQDBMFileNm, Depot.OWRITER | Depot.OCREAT, -1);
      }
    catch (Exception exc)
      {
      exc.printStackTrace();
      System.exit(1);
      }
    // Reade The Pipe Delimited CSV File; Post Year and Horse Name to QDBM File
    try 
      {
      BufferedReader rdrCSVFl = new BufferedReader(new FileReader(args[0]));
      String inline = null;
      String sYr = "";
      String sHorseNm = "";
      int iRecCnt = 0;
      int iFldCnt = 0;
      while ((inline=rdrCSVFl.readLine()) != null)
        {   
        String[] arrFlds = inline.split("\\|");
        iFldCnt = 0;
        for (String Fld : arrFlds) 
          {
          iFldCnt++;
          if (iFldCnt == 1)
            {
            sYr = Fld;
            }
          if (iFldCnt == 2)
            {
            sHorseNm = Fld;
            }
          }
        iRecCnt++;
        System.out.print(iRecCnt + ": ");
        System.out.println(" -- Year: " + sYr + " -- Horse: " + sHorseNm);
        // Store the QDBM Record
        depot.put(sYr.getBytes(), sHorseNm.getBytes());
        }
      rdrCSVFl.close();
      } 
    catch(DepotException e)
      {
      e.printStackTrace();
      System.exit(1);
      } 
    catch (IOException e)
      {
      e.printStackTrace();
      System.exit(1);
      }
    finally 
      {
      // close the database
      if(depot != null)
        {
        try 
          {
          depot.close();
          } 
        catch(DepotException e)
          {
          e.printStackTrace();
          }
        }
      }
	  endmsg();
	  System.exit(0);
    } // End main method
  
  public static void banner()
    {
	  System.out.println("LdQDBMHorseOfYr.java");
	  System.out.println("Load QDBM File With Eclipse Horse of The Year Data Using QDBM Depot");
	  System.out.println("Version 1.0");
	  System.out.println("Written By: Tony Dycks");
	  System.out.println("Revised By: Tony Dycks");
	  System.out.println("Date Written: April 27, 2020");
	  System.out.println("Date Revised: April 28, 2020");
	  System.out.println("");
    }
    
  public static void endmsg()
    {
	  System.out.println("");
	  System.out.println(">>> End Of Program -- LdQDBMHorseOfYr.java <<<");
	  System.out.println("");
    }
    
  public static String getqdbmfilenm()
    {
    String sArgFileNm = "";
    try
      {
      sArgFileNm = System.getenv("HOME") + "/qdbm/appl/eclipsehorseofyr.qdb";
      }
    catch (Exception exc)
      {
      exc.printStackTrace();
      System.exit(1);
      }
    return sArgFileNm;
    }
    
  } // End class LdQDBMHorseOfYr



