// PROGRAM-NAME: LdTCHHorseOfYr.java       BACKUP-REQUIRED: Yes
// AUTHOR: Tony Dycks                      REVISED-BY: Tony Dycks
// DATE-WRITTEN: May 5, 2020               DATE-REVISED: May 27, 2020
// LANGUAGE: Java 8 SE  or JDK             VERSION NO.: 1.8+
// PLATFORM: Windows/Linux (Command Shell) VERSION NO.: 7/10 / CentOs/Debian
//
// DESCRIPTION:
//   Load Hash DB File With Eclipse Horse of The Year Data Using Tokyo Cabinet 
//
// PRE-REQUISITE(S):
//   1. Installation of tokyocabinet-dev Binary or Source Package 
//   2. Download And Installation of tokyocabinet-java Source Package
//   3. Copy tokyocabinet.jar File to $JAVA_HOME/jre/lib/ext Directory
//
// REVISION HISTORY:
//   Version  Change Description
//   =======  ====================================================
//     1.0    Original Implementation
//              T. Dycks -- May 5, 2020
//     1.1    Cleanup Documentaton
//              T. Dycks -- May 14, 2020
//     1.2    Fix Bug With Loading of Duplicate Keys
//              T. Dycks -- May 27, 2020
//
// COMPILE:
//   javac LdTCHHorseOfYr.java  <Enter>
//
// USAGE:
//   java LdTCHHorseOfYr.java <HorseOfTheYr-CSV-File> <Enter>
//
// USAGE EXAMPLE(S):
//   java LdTCHHorseOfYr $HOME/txtfiles/eclipsehorseofyr.txt <Enter>
//
// REFERENCE(S):
//   Tokyo Cabinet: a modern implementation of DBM
//   Copyright (C) 2006-2011 FAL Labs
//   Last Update: Thu, 05 Aug 2010 
// URL:
//   https://fallabs.com/tokyocabinet/
// ================================================================================
//   Fallabs.com -- Presentation -- Introduction to Tokyo Products PDF 
// URL:
//   ps://fallabs.com/tokyocabinet/tokyoproducts.pdf
// ================================================================================
//   Fallabs.com -- Specifications of the Java API
// URL:
//   https://fallabs.com/tokyocabinet/javadoc
//
import java.io.*;
import tokyocabinet.*;

public class LdTCHHorseOfYr
  {
  public static void main(String args[])
    {
	  banner();
    String sTCHFileNm = gettchfilenm();
    // Open the TCH Database File; Create It If Necessary
    HDB tchdb = new HDB();
    try
      {
      tchdb.open(sTCHFileNm, HDB.OWRITER | HDB.OCREAT);
      // If Records Exist From Previous Load; Purge Them
      //   T. Dycks -- May 27, 2020
      if (tchdb.rnum() > 0)
        {
        System.out.print("Record Count: ");
        System.out.println(tchdb.rnum());
        if (tchdb.vanish())
          {
          System.out.println("Previous Records Purged OK ...\n");
          }
        }
      }
    catch (Exception exc)
      {
      exc.printStackTrace();
      System.exit(1);
      }
    // Read The Pipe Delimited CSV File; Post Year and Horse Name to QDBM File
    try 
      {
      BufferedReader rdrCSVFl = new BufferedReader(new FileReader(args[0]));
      String inline = null;
      String sYr = "";
      String sHorseNm = "";
      int iRecCnt = 0;
      int iFldCnt = 0;
      while ((inline=rdrCSVFl.readLine()) != null)
        {   
        String[] arrFlds = inline.split("\\|");
        iFldCnt = 0;
        for (String Fld : arrFlds) 
          {
          iFldCnt++;
          if (iFldCnt == 1)
            {
            sYr = Fld;
            }
          if (iFldCnt == 2)
            {
            sHorseNm = Fld;
            }
          }
        iRecCnt++;
        System.out.print(iRecCnt + ": ");
        System.out.println(" -- Year: " + sYr + " -- Horse: " + sHorseNm);
        // Store the QDBM Record
        tchdb.put(sYr, sHorseNm);
        }
      rdrCSVFl.close();
      }
    catch (IOException e)
      {
      e.printStackTrace();
      System.exit(1);
      }      
    catch(Exception e)
      {
      e.printStackTrace();
      System.exit(1);
      } 
    finally 
      {
      // close the database
      if(tchdb != null)
        {
        try 
          {
          tchdb.close();
          } 
        catch(Exception e)
          {
          e.printStackTrace();
          }
        }
      }
	  endmsg();
	  System.exit(0);
    } // End main method
  
  public static void banner()
    {
	  System.out.println("LdTCHHorseOfYr.java");
	  System.out.println("Load TC Hash File With Eclipse Horse of The Year Data Using Tokyo Cabinet");
	  System.out.println("Version 1.2");
	  System.out.println("Written By: Tony Dycks");
	  System.out.println("Revised By: Tony Dycks");
	  System.out.println("Date Written: May 5, 2020");
	  System.out.println("Date Revised: May 27, 2020");
	  System.out.println("");
    }
    
  public static void endmsg()
    {
	  System.out.println("");
	  System.out.println(">>> End Of Program -- LdTCHHorseOfYr.java <<<");
	  System.out.println("");
    }
    
  public static String gettchfilenm()
    {
    String sArgFileNm = "";
    try
      {
      sArgFileNm = System.getenv("HOME") + "/tokyocab/appl/eclipsehorseofyr.tch";
      }
    catch (Exception exc)
      {
      exc.printStackTrace();
      System.exit(1);
      }
    return sArgFileNm;
    }
    
  } // End class LdTCHHorseOfYr
